@@ -2,7 +2,7 @@
 # Kernel/Language/fi.pm - provides fi language translation
 # Copyright (C) 2002 Antti Kmrinen <antti at seu.net>
 # --
-# $Id: fi.pm,v 1.10 2003/02/03 22:53:09 martin Exp $
+# $Id: fi.pm,v 1.15 2003/04/12 23:03:37 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,8 +13,8 @@ package Kernel::Language::fi;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.10 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*\$/$1/;
+$VERSION = '$Revision: 1.15 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 # --
 sub Data {
     my $Self = shift;
@@ -22,7 +22,7 @@ sub Data {
     my %Hash = ();
 
     # $$START$$
-    # Last translation Mon Feb  3 23:33:29 2003 by 
+    # Last translation Sun Apr 13 01:00:15 2003 by 
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
@@ -40,18 +40,20 @@ sub Data {
       '15 minutes' => '15 Minuuttia',
       'AddLink' => 'Lis linkki',
       'AdminArea' => 'Yllpito',
+      'agent' => '',
       'all' => 'kaikki',
       'All' => 'Kaikki',
       'Attention' => 'Huomio',
       'Bug Report' => 'Lhet bugiraportti',
       'Cancel' => 'Peruuta',
-      'Change' => 'Muuta',
       'change' => 'muuta',
+      'Change' => 'Muuta',
       'change!' => 'muuta!',
       'click here' => 'klikkaa tst',
       'Comment' => 'Kommentti',
       'Customer' => 'Asiakas',
-      'Customer info' => 'Tietoa asiakkaasta',
+      'customer' => '',
+      'Customer Info' => 'Tietoa asiakkaasta',
       'day' => 'piv',
       'days' => 'piv',
       'description' => 'Selitys',
@@ -65,7 +67,7 @@ sub Data {
       'Example' => 'Esimerkki',
       'Examples' => 'Esimerkit',
       'Facility' => '',
-      'Feature not acitv!' => 'Ominaisuus ei kytss',
+      'Feature not active!' => 'Ominaisuus ei kytss',
       'go' => 'mene',
       'go!' => 'mene!',
       'Group' => 'Ryhm',
@@ -90,16 +92,17 @@ sub Data {
       'Name' => 'Nimi',
       'New message' => 'Uusi viesti',
       'New message!' => 'Uusi viesti!',
-      'no' => 'ei',
       'No' => 'Ei',
+      'no' => 'ei',
+      'No entry found!' => '',
       'No suggestions' => 'Ei ehdotusta',
       'none' => 'ei mitn',
       'none - answered' => 'ei mitn - vastattu',
       'none!' => 'ei mitn!',
-      'off' => 'pois',
       'Off' => 'Pois',
-      'on' => 'pll',
+      'off' => 'pois',
       'On' => 'Pll',
+      'on' => 'pll',
       'Password' => 'Salasana',
       'Pending till' => 'Odottaa',
       'Please answer this ticket(s) to get back to the normal queue view!' => 'Vastaa thn viestiin saadaksesi se takaisin normaalille jonotuslistalle',
@@ -111,12 +114,14 @@ sub Data {
       'replace with' => 'Korvaa',
       'Reset' => 'Tyhjenn',
       'Salutation' => 'Tervehdys',
+      'Session has timed out. Please log in again.' => '',
       'Signature' => 'Allekirjoitus',
       'Sorry' => 'Anteeksi',
       'Stats' => 'Tilastot',
       'Subfunction' => 'Alifunktio',
       'submit' => 'lhet',
       'submit!' => 'lhet!',
+      'system' => '',
       'Take this User' => '',
       'Text' => 'Teksti',
       'The recommended charset for your language is %s!' => 'Suositeltava kirjainasetus kielellesi on %s',
@@ -133,8 +138,8 @@ sub Data {
       'Welcome to OTRS' => 'Tervetuloa kyttmn OTRS-jrjestelm',
       'Word' => 'Sana',
       'wrote' => 'kirjoittaa',
-      'Yes' => 'Kyll',
       'yes' => 'kyll',
+      'Yes' => 'Kyll',
       'You got new message!' => 'Sinulla on uusi viesti!',
       'You have %s new message(s)!' => 'Sinulla on %s kpl uusia viesti!',
       'You have %s reminder ticket(s)!' => 'Sinulla on %s muistutettavaa viesti!',
@@ -154,6 +159,7 @@ sub Data {
       'Sep' => 'Syys',
 
     # Template: AAAPreferences
+      'Closed Tickets' => '',
       'Custom Queue' => 'Valitsemasi jonotuslistat',
       'Follow up notification' => 'Ilmoitus jatkokysymyksist',
       'Frontend' => 'Kyttliittym',
@@ -163,6 +169,7 @@ sub Data {
       'Other Options' => 'Muita asetuksia',
       'Preferences updated successfully!' => 'Asetukset tallennettu onnistuneesti',
       'QueueView refresh time' => 'Jonotusnkymn pivitysaika',
+      'Select your default spelling dictionary.' => '',
       'Select your frontend Charset.' => 'Valitse kyttliittymn kirjaisinasetukset',
       'Select your frontend language.' => 'Valitse kyttliittymn kieli',
       'Select your frontend QueueView.' => 'Valitse kyttliittymsi jonotusnkym',
@@ -172,6 +179,8 @@ sub Data {
       'Send me a notification if a ticket is moved into a custom queue.' => 'Lhet minulle ilmoitus, jos tikettej siirretn valitsemiini jonoihin',
       'Send me a notification if a ticket is unlocked by the system.' => 'Lhet minulle ilmoitus, jos jrjestelm poistaa tiketin lukituksen.',
       'Send me a notification if there is a new ticket in my custom queues.' => 'Lhet ilmoitus uusista tiketeist, jotka tulevat valitsemilleni jonotuslistoille',
+      'Show closed tickets.' => '',
+      'Spelling Dictionary' => '',
       'Ticket lock timeout notification' => 'Ilmoitus tiketin lukituksen vanhenemisesta',
 
     # Template: AAATicket
@@ -203,6 +212,7 @@ sub Data {
       'high' => 'Kiireellinen',
       'History' => 'Historia',
       'If it is not displayed correctly,' => 'Jos tm ei ny oikein,',
+      'lock' => '',
       'Lock' => 'Lukitse',
       'low' => 'Alhainen',
       'Move' => 'Siirr',
@@ -232,6 +242,7 @@ sub Data {
       'Ticket' => 'Tiketti',
       'To' => 'Vastaanottaja',
       'to open it in a new window.' => 'avataksesi se uuteen ikkunaan.',
+      'unlock' => 'poista lukitus',
       'Unlock' => 'Poista lukitus',
       'very high' => 'Erittin kiireellinen',
       'very low' => 'Erittin alhainen',
@@ -289,7 +300,9 @@ sub Data {
       'Admin-Email' => 'Yllpidon shkposti',
       'Body' => 'Runko-osa',
       'OTRS-Admin Info!' => '',
+      'Permission' => '',
       'Recipents' => 'Vastaanottajat',
+      'send' => '',
 
     # Template: AdminEmailSent
       'Message sent to' => 'Viesti lhetetty, vastaanottaja: ',
@@ -302,17 +315,13 @@ sub Data {
       'It\'s useful for ASP solutions.' => 'Tm on hydyllinen ASP-kytss',
       'The admin group is to get in the admin area and the stats group to get stats area.' => 'Admin-ryhmn jsenet psevt yllpito- ja tilastoalueille.',
 
-    # Template: AdminLanguageForm
-      'Add language' => 'Lis kieli',
-      'Change system language setting' => 'Muokkaa jrjestelmn kieliasetuksua',
-      'System Language Management' => 'Jrjestelmn kielen hallinta',
-
     # Template: AdminLog
       'System Log' => 'Jrjestelmlogi',
 
     # Template: AdminNavigationBar
       'AdminEmail' => 'Yllpidon shkposti',
       'AgentFrontend' => 'Tukinkym',
+      'Attachment <-> Response' => '',
       'Auto Response <-> Queue' => 'Automaattivastaukset <-> Jonotuslista',
       'Auto Responses' => 'Automaattivastaukset',
       'Charsets' => 'Kirjaisinasetus',
@@ -326,7 +335,7 @@ sub Data {
       'Responses <-> Queue' => 'Vastaukset <-> Jonotuslista',
       'Select Box' => 'Suodatus',
       'Session Management' => 'Istuntojen hallinta',
-      'Status defs' => 'Tikettien tilamritykset',
+      'Status' => '',
       'System' => 'Jrjestelm',
       'User <-> Groups' => 'Kyttj <-> Ryhmt',
 
@@ -351,13 +360,20 @@ sub Data {
       '0 = no unlock' => '0 = ei lukituksen poistumista',
       'Add queue' => 'Lis jonotuslista',
       'Change queue settings' => 'Muuta jonotuslistan asetuksia',
+      'Customer Move Notify' => '',
+      'Customer Owner Notify' => '',
+      'Customer State Notify' => '',
       'Escalation time' => 'Maksimi ksittelyaika',
       'Follow up Option' => 'Seuranta-asetukset',
       'If a ticket is closed and the customer sends a follow up the ticket will be locked for the old owner.' => '',
       'If a ticket will not be answered in thos time, just only this ticket will be shown.' => '',
       'If an agent locks a ticket and he/she will not send an answer within this time, the ticket will be unlock automatically. So the ticket is viewable for all other agents.' => '',
       'Key' => 'Key',
+      'OTRS sends an notification email to the customer if the ticket is moved.' => '',
+      'OTRS sends an notification email to the customer if the ticket owner has changed.' => '',
+      'OTRS sends an notification email to the customer if the ticket state has changed.' => '',
       'Queue Management' => 'Jonotuslistan Hallinta',
+      'Sub-Queue of' => '',
       'Systemaddress' => 'Jrjestelmn osoite',
       'The salutation for email answers.' => '',
       'The signature for email answers.' => 'Allekirjoitus shkpostiosoitteeseen',
@@ -390,6 +406,10 @@ sub Data {
       'Add salutation' => 'Lis tervehdys',
       'Change salutation settings' => 'Muuta tervehdysasetuksia',
       'customer realname' => 'kyttjn oikea nimi',
+      'for agent firstname' => 'ksittelijn etunimi',
+      'for agent lastname' => 'ksittelijn sukunimi',
+      'for agent login' => '',
+      'for agent user id' => '',
       'Salutation Management' => 'Tervehdysten hallinta',
 
     # Template: AdminSelectBoxForm
@@ -410,13 +430,12 @@ sub Data {
     # Template: AdminSignatureForm
       'Add signature' => 'Lis allekirjoitus',
       'Change signature settings' => 'Muuta allekirjoitusasetuksia',
-      'for agent firstname' => 'ksittelijn etunimi',
-      'for agent lastname' => 'ksittelijn sukunimi',
       'Signature Management' => 'Allekirjoitusten hallinta',
 
     # Template: AdminStateForm
       'Add state' => 'Lis uusi tila',
       'Change system state setting' => 'Muuta tiketin tila-asetuksia',
+      'State Type' => '',
       'System State Management' => 'Tilamahdollisuuksien mrittminen',
 
     # Template: AdminSystemAddressForm
@@ -453,38 +472,45 @@ sub Data {
       'Next ticket state' => 'Uusi tiketin status',
       'Send mail!' => 'Lhet shkposti!',
       'You need a email address (e. g. customer@example.com) in To:!' => 'Laita vastaanottajakenttn shkpostiosoite!',
-      'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further inforamtions.' => 'Shkposti, tikettinumero "<OTRS_TICKET>" on vlitetty osoitteeseen: "<OTRS_BOUNCE_TO>" . Ota yhteytt kyseiseen osoitteeseen saadaksesi listietoja',
+      'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'Shkposti, tikettinumero "<OTRS_TICKET>" on vlitetty osoitteeseen: "<OTRS_BOUNCE_TO>" . Ota yhteytt kyseiseen osoitteeseen saadaksesi listietoja',
 
     # Template: AgentClose
       ' (work units)' => '',
+      'A message should have a subject!' => 'Viestiss pit olla otsikko!',
       'Close ticket' => 'Sulje tiketti',
       'Close type' => 'Sulkemisen syy',
       'Close!' => 'Sulje!',
       'Note Text' => 'Huomautusteksti',
       'Note type' => 'Viestityyppi',
-      'store' => 'tallenna',
+      'Options' => 'Asetukset',
+      'Spell Check' => 'Oikeinkirjoituksen tarkistus',
       'Time units' => 'Aikayksikt',
+      'You need to account time!' => '',
 
     # Template: AgentCompose
-      'A message should have a subject!' => 'Viestiss pit olla otsikko!',
+      'A message must be spell checked!' => '',
       'Attach' => 'Liite',
       'Compose answer for ticket' => 'Lhet vastaus tikettiin',
       'for pending* states' => '',
       'Is the ticket answered' => '',
-      'Options' => 'Asetukset',
       'Pending Date' => 'Odotuspiv',
-      'Spell Check' => 'Oikeinkirjoituksen tarkistus',
 
     # Template: AgentCustomer
       'Back' => 'Takaisin',
       'Change customer of ticket' => 'Vaihda tiketin asiakasta',
-      'Set customer id of a ticket' => 'Aseta tiketin asiakasnumero#',
+      'CustomerID' => 'AsiakasID#',
+      'Search Customer' => 'Etsi Asiakas',
+      'Set customer user and customer id of a ticket' => '',
 
     # Template: AgentCustomerHistory
       'Customer history' => 'Asiakkaan historiatiedot',
 
     # Template: AgentCustomerHistoryTable
 
+    # Template: AgentCustomerMessage
+      'Follow up' => 'Ilmoitukset',
+      'Next state' => '',
+
     # Template: AgentCustomerView
       'Customer Data' => '',
 
@@ -496,12 +522,15 @@ sub Data {
       'Forwarded message from' => 'Vlitetty viesti. Lhettj:',
       'Reply-To' => 'Lhet vastaus',
 
+    # Template: AgentFreeText
+      'Change free text of ticket' => '',
+      'Value' => '',
+
     # Template: AgentHistoryForm
       'History of' => '',
 
     # Template: AgentMailboxNavBar
       'All messages' => 'Kaikki viestit',
-      'CustomerID' => 'AsiakasID#',
       'down' => 'loppuun',
       'Mailbox' => 'Saapuneet',
       'New' => 'Uusi',
@@ -517,10 +546,13 @@ sub Data {
       'up' => 'alkuun',
 
     # Template: AgentMailboxTicket
-      'Add Note' => 'Lis huomautus',
+
+    # Template: AgentMove
+      'Move Ticket' => '',
+      'New Queue' => '',
+      'New user' => 'Uusi kyttj',
 
     # Template: AgentNavigationBar
-      'FAQ' => 'FAQ/UKK',
       'Locked tickets' => 'Lukitut tiketit',
       'new message' => 'uusi viesti',
       'PhoneView' => 'Puhelu / Uusi tiketti',
@@ -534,11 +566,11 @@ sub Data {
     # Template: AgentOwner
       'Change owner of ticket' => 'Muuta tmn tiketin omistajaa',
       'Message for new Owner' => '',
-      'New user' => 'Uusi kyttj',
 
     # Template: AgentPending
       'Pending date' => '',
       'Pending type' => '',
+      'Pending!' => '',
       'Set Pending' => '',
 
     # Template: AgentPhone
@@ -547,7 +579,8 @@ sub Data {
       'Phone call at %s' => 'Puhelu %s',
 
     # Template: AgentPhoneNew
-      'Search Customer' => 'Etsi Asiakas',
+      'Clear From' => '',
+      'create' => '',
       'new ticket' => 'Uusi tiketti',
 
     # Template: AgentPlain
@@ -582,9 +615,10 @@ sub Data {
 
     # Template: AgentStatusView
       'D' => 'A',
+      'of' => '',
+      'Site' => 'Palvelin',
       'sort downward' => 'Jrjest laskevasti',
       'sort upward' => 'Jrjest nousevasti',
-      'Ticket limit:' => 'Tikettien max mr',
       'Ticket Status' => 'Tiketin tilatieto',
       'U' => 'Y',
 
@@ -594,7 +628,7 @@ sub Data {
 
     # Template: AgentTicketLocked
       'Ticket locked!' => 'Tiketti lukittu!',
-      'unlock' => 'poista lukitus',
+      'Ticket unlock!' => '',
 
     # Template: AgentTicketPrint
       'by' => '',
@@ -604,45 +638,60 @@ sub Data {
       'Escalation in' => 'Vanhenee',
       'printed by' => '',
 
+    # Template: AgentUtilSearch
+      'Article free text' => '',
+      'Fulltext search (e. g. "Mar*in" or "Baue*" or "martin+hallo")' => 'Tekstihaku("Etsi esimerkiksi "Mi*a" tai "Petr+Tekrat"',
+      'search' => 'Etsi',
+      'search (e. g. 10*5155 or 105658*)' => 'etsi tikettinumerolla (Esim. 10*5155 or 105658*)',
+      'Ticket free text' => 'Etsi koko tiketist',
+      'Ticket Search' => '',
+
     # Template: AgentUtilSearchByCustomerID
       'Customer history search' => 'Asiakashistoriahaku',
       'Customer history search (e. g. "ID342425").' => 'Asiakashistoriahaku (Esim. "ID342425").',
       'No * possible!' => 'Jokerimerkki (*) ei kytss !',
 
-    # Template: AgentUtilSearchByText
-      'Article free text' => '',
-      'Fulltext search' => 'Tekstihaku',
-      'Fulltext search (e. g. "Mar*in" or "Baue*" or "martin+hallo")' => 'Tekstihaku("Etsi esimerkiksi "Mi*a" tai "Petr+Tekrat"',
-      'Search in' => 'Etsi seuraavista:',
-      'Ticket free text' => 'Etsi koko tiketist',
-      'With State' => '',
-
-    # Template: AgentUtilSearchByTicketNumber
-      'search' => 'Etsi',
-      'search (e. g. 10*5155 or 105658*)' => 'etsi tikettinumerolla (Esim. 10*5155 or 105658*)',
-
     # Template: AgentUtilSearchNavBar
       'Results' => 'Hakutulokset',
-      'Site' => 'Palvelin',
       'Total hits' => 'Hakutuloksia yhteens',
 
     # Template: AgentUtilSearchResult
 
     # Template: AgentUtilTicketStatus
+      'All closed tickets' => '',
       'All open tickets' => 'Kaikki avoimet tiketit',
+      'closed tickets' => '',
       'open tickets' => 'avoimet tiketit',
+      'or' => '',
       'Provides an overview of all' => '',
       'So you see what is going on in your system.' => '',
 
+    # Template: AgentZoomAgentIsCustomer
+      'Compose Follow up' => '',
+      'Your own Ticket' => '',
+
+    # Template: AgentZoomAnswer
+      'Compose Answer' => 'Vastaa',
+      'Contact customer' => 'Ota yhteytt asiakkaaseen',
+      'phone call' => 'Puhelut',
+
+    # Template: AgentZoomArticle
+      'Split' => '',
+
+    # Template: AgentZoomBody
+      'Change queue' => 'Vaihda jonotuslistaa',
+
+    # Template: AgentZoomHead
+      'Free Fields' => '',
+      'Print' => '',
+
+    # Template: AgentZoomStatus
+
     # Template: CustomerCreateAccount
-      'Create' => 'Luo',
       'Create Account' => 'Luo tunnus',
 
     # Template: CustomerError
-      'Backend' => '',
-      'BackendMessage' => '',
-      'Click here to report a bug!' => 'Klikkaa tst lhettksesi bugiraportti!',
-      'Handle' => '',
+      'Traceback' => '',
 
     # Template: CustomerFooter
       'Powered by' => '',
@@ -661,7 +710,6 @@ sub Data {
       'Request new password' => 'Pyyd uutta salasanaa',
 
     # Template: CustomerMessage
-      'Follow up' => 'Ilmoitukset',
 
     # Template: CustomerMessageNew
 
@@ -679,7 +727,6 @@ sub Data {
     # Template: CustomerPreferencesPassword
 
     # Template: CustomerStatusView
-      'of' => '',
 
     # Template: CustomerStatusViewTable
 
@@ -688,13 +735,48 @@ sub Data {
     # Template: CustomerWarning
 
     # Template: Error
+      'Click here to report a bug!' => 'Klikkaa tst lhettksesi bugiraportti!',
 
     # Template: Footer
+      'Top of Page' => '',
 
     # Template: Header
 
+    # Template: InstallerBody
+      'Create Database' => '',
+      'Drop Database' => '',
+      'Finished' => '',
+      'System Settings' => '',
+      'Web-Installer' => '',
+
+    # Template: InstallerFinish
+      'Admin-User' => '',
+      'After doing so your OTRS is up and running.' => '',
+      'Have a lot of fun!' => '',
+      'Restart your webserver' => '',
+      'Start page' => '',
+      'To be able to use OTRS you have to enter the following line in your command line (Terminal/Shell) as root.' => '',
+      'Your OTRS Team' => '',
+
+    # Template: InstallerLicense
+      'accept license' => '',
+      'don\'t accept license' => '',
+      'License' => '',
+
     # Template: InstallerStart
+      'Create new database' => '',
+      'DB Admin Password' => '',
+      'DB Admin User' => '',
+      'DB Host' => '',
+      'DB Type' => '',
+      'default \'hot\'' => '',
+      'Delete old database' => '',
       'next step' => 'Seuraava',
+      'OTRS DB connect host' => '',
+      'OTRS DB Name' => '',
+      'OTRS DB Password' => '',
+      'OTRS DB User' => '',
+      'your MySQL DB should have a root password! Default is empty!' => '',
 
     # Template: InstallerSystem
       '(Checks MX recordes of used email addresses by composing an answer. Don\'t use CheckMXRecord if your OTRS machine is behinde a dial-up line $!)' => '',
@@ -732,14 +814,11 @@ sub Data {
       'URL' => '',
 
     # Template: PrintHeader
-      'Print' => '',
 
     # Template: QueueView
       'All tickets' => 'Tikettej yhteens',
       'Queues' => 'Jonotuslista',
-      'Show all' => 'Yhteens',
-      'Ticket available' => 'Tikettej avoinna',
-      'tickets' => 'tiketti',
+      'Tickets available' => 'Tikettej avoinna',
       'Tickets shown' => 'Tikettej nkyviss',
 
     # Template: SystemStats
@@ -752,18 +831,9 @@ sub Data {
       'Ticket escalation!' => 'Tiketin maksimi hyvksyttv ksittelyaika!',
 
     # Template: TicketView
-      'Change queue' => 'Vaihda jonotuslistaa',
-      'Compose Answer' => 'Vastaa',
-      'Contact customer' => 'Ota yhteytt asiakkaaseen',
-      'phone call' => 'Puhelut',
 
     # Template: TicketViewLite
-
-    # Template: TicketZoom
-
-    # Template: TicketZoomNote
-
-    # Template: TicketZoomSystem
+      'Add Note' => 'Lis huomautus',
 
     # Template: Warning
 
@@ -780,7 +850,21 @@ sub Data {
       '(Click here to add language)' => '(Klikkaa tst listksesi uusi kieli)',
       '(Click here to add state)' => '(Klikkaa tst listksesi uusi status)',
       'A message should have a From: recipient!' => '',
+      'Add language' => 'Lis kieli',
+      'Backend' => '',
+      'BackendMessage' => '',
+      'Change system language setting' => 'Muokkaa jrjestelmn kieliasetuksua',
+      'Create' => 'Luo',
+      'FAQ' => 'FAQ/UKK',
+      'Fulltext search' => 'Tekstihaku',
+      'Handle' => '',
       'New ticket via call.' => 'Uusi ',
+      'Search in' => 'Etsi seuraavista:',
+      'Set customer id of a ticket' => 'Aseta tiketin asiakasnumero#',
+      'Show all' => 'Yhteens',
+      'Status defs' => 'Tikettien tilamritykset',
+      'System Language Management' => 'Jrjestelmn kielen hallinta',
+      'Ticket limit:' => 'Tikettien max mr',
       'Time till escalation' => 'Aikaa jljell maksimi ksittelyaikaan',
       'Update auto response' => 'Pivit automaattivastaukset',
       'Update charset' => 'Pivit kirjaisinasetukset',
@@ -793,10 +877,13 @@ sub Data {
       'Update state' => 'Pivit status',
       'Update system address' => 'Pivit jrjestelmn shkpostiosoitetta',
       'Update user' => 'Pivit kyttjtiedot',
+      'With State' => '',
       'You have to be in the admin group!' => 'Sinun tytyy olla admin -ryhmss!',
       'You have to be in the stats group!' => 'Sinun tytyy olla stats -ryhmss',
       'You need a email address (e. g. customer@example.com) in From:!' => 'Lhettj -kentss pit olla shkpostiosoite (esim. teppo.testi@esimerkki.fi)',
       'auto responses set' => '',
+      'store' => 'tallenna',
+      'tickets' => 'tiketti',
     );
 
     # $$STOP$$
