@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentZoom.pm - to get a closer view
 # Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: AgentZoom.pm,v 1.28 2003/02/03 19:45:58 martin Exp $
+# $Id: AgentZoom.pm,v 1.34 2003/04/27 16:10:05 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,10 +12,11 @@
 package Kernel::Modules::AgentZoom;
 
 use strict;
+use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.28 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = '$Revision: 1.34 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
 sub new {
@@ -63,6 +64,7 @@ sub Run {
     # check permissions
     # --
     if (!$Self->{TicketObject}->Permission(
+        Type => 'ro',
         TicketID => $Self->{TicketID},
         UserID => $Self->{UserID})) {
         # --
@@ -93,7 +95,10 @@ sub Run {
         %MoveQueues = $Self->{QueueObject}->GetAllQueues();
     }
     else {
-        %MoveQueues = $Self->{QueueObject}->GetAllQueues(UserID => $Self->{UserID});
+        %MoveQueues = $Self->{QueueObject}->GetAllQueues(
+            UserID => $Self->{UserID},
+            Type => 'rw',
+        );
     }
     # --
     # fetch all std. responses
@@ -117,12 +122,12 @@ sub Run {
     " st.create_time_unix, st.tn, st.user_id, st.ticket_state_id, st.ticket_priority_id, ". 
     " sa.create_time, stt.name as sender_type, at.name as article_type, ".
     " su.$Self->{ConfigObject}->{DatabaseUserTableUser}, ".
-    " sl.name as lock_type, sp.name as priority, tsd.name as state, sa.content_path, ".
+    " sl.name as lock_type, sp.name as priority, sp.id as priority_id, tsd.name as state, sa.content_path, ".
     " sq.name as queue, st.create_time as ticket_create_time, ".
     " sa.a_freekey1, sa.a_freetext1, sa.a_freekey2, sa.a_freetext2, ".
     " sa.a_freekey3, sa.a_freetext3, st.freekey1, st.freekey2, st.freetext1, ".
-    " st.freetext2, st.customer_id, sq.group_id, st.ticket_answered, sq.escalation_time, ".
-    " sa.a_content_type, sa.incoming_time, st.until_time ".
+    " st.freetext2, st.customer_id, st.customer_user_id, sq.group_id, st.ticket_answered, ".
+    " sq.escalation_time, sa.a_content_type, sa.incoming_time, st.until_time ".
     " FROM ".
     " article sa, ticket st, article_sender_type stt, article_type at, ".
     " $Self->{ConfigObject}->{DatabaseUserTable} su, ticket_lock_type sl, " .
@@ -149,12 +154,12 @@ sub Run {
     " st.create_time_unix, st.tn, st.user_id, st.ticket_state_id, st.ticket_priority_id, ".
     " sa.create_time, stt.name, at.name, ".
     " su.$Self->{ConfigObject}->{DatabaseUserTableUser}, ".
-    " sl.name, sp.name, tsd.name, sa.content_path, ".
+    " sl.name, sp.name, sp.id, tsd.name, sa.content_path, ".
     " sq.name, st.create_time, ".
     " sa.a_freekey1, sa.a_freetext1, sa.a_freekey2, sa.a_freetext2, ".
     " sa.a_freekey3, sa.a_freetext3, st.freekey1, st.freekey2, st.freetext1, ".
-    " st.freetext2, st.customer_id, sq.group_id, st.ticket_answered, sq.escalation_time, ".
-    " sa.a_content_type, sa.incoming_time, st.until_time ";
+    " st.freetext2, st.customer_id, st.customer_user_id, sq.group_id, st.ticket_answered, ".
+    " sq.escalation_time, sa.a_content_type, sa.incoming_time, st.until_time ";
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my $Data = $Self->{DBObject}->FetchrowHashref() ) {
         # get escalation_time
@@ -171,11 +176,13 @@ sub Run {
         $Ticket{TicketNumber} = $$Data{tn};
         $Ticket{State} = $$Data{state};
         $Ticket{CustomerID} = $$Data{customer_id};
+        $Ticket{CustomerUserID} = $$Data{customer_user_id};
         $Ticket{Queue} = $$Data{queue};
         $Ticket{QueueID} = $QueueID;
         $Ticket{Lock} = $$Data{lock_type};
         $Ticket{Owner} = $$Data{login};
         $Ticket{Priority} = $$Data{priority};
+        $Ticket{PriorityID} = $$Data{priority_id};
         $Ticket{TicketFreeKey1} = $$Data{freekey1};
         $Ticket{TicketFreeValue1} = $$Data{freetext1};
         $Ticket{TicketFreeKey2} = $$Data{freekey2};
@@ -190,11 +197,11 @@ sub Run {
         $Article{ArticleType} = $$Data{article_type};
         $Article{SenderType} = $$Data{sender_type};
         $Article{ArticleID} = $$Data{id};
-        $Article{From} = $$Data{a_from} || ' ';
-        $Article{To} = $$Data{a_to} || ' ';
-        $Article{Cc} = $$Data{a_cc} || ' ';
-        $Article{Subject} = $$Data{a_subject} || ' ';
-        $Article{Text} = $$Data{a_body};
+        $Article{From} = $$Data{a_from} || '';
+        $Article{To} = $$Data{a_to} || '';
+        $Article{Cc} = $$Data{a_cc} || '';
+        $Article{Subject} = $$Data{a_subject} || '';
+        $Article{Body} = $$Data{a_body};
         $Article{CreateTime} = $$Data{create_time};
         $Article{FreeKey1} = $$Data{a_freekey1};
         $Article{FreeValue1} = $$Data{a_freetext1};
@@ -224,10 +231,17 @@ sub Run {
     # customer info
     # --
     my %CustomerData = ();
-    if ($Ticket{CustomerID}) { 
-        %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-            CustomerID => $Ticket{CustomerID},
-        );
+    if ($Self->{ConfigObject}->Get('ShowCustomerInfoZoom')) {
+        if ($Ticket{CustomerUserID}) {
+            %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                User => $Ticket{CustomerUserID},
+            );
+        }
+        elsif ($Ticket{CustomerID}) {
+            %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                CustomerID => $Ticket{CustomerID},
+            );
+        }
     }
     # --
     # genterate output
@@ -243,7 +257,7 @@ sub Run {
         $Ticket{ShowHTMLeMail} = 1;
         $Output = '';
     }
-    $Output .= $Self->{LayoutObject}->TicketZoom(
+    $Output .= $Self->{LayoutObject}->AgentZoom(
         TicketID => $Self->{TicketID},
         QueueID => $QueueID,
         MoveQueues => \%MoveQueues,
