@@ -2,7 +2,7 @@
 # HTML/Installer.pm - provides installer HTML output
 # Copyright (C) 2002-2003 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Installer.pm,v 1.5 2003/02/03 21:18:29 martin Exp $
+# $Id: Installer.pm,v 1.7 2003/04/12 20:11:42 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,20 +14,9 @@ package Kernel::Output::HTML::Installer;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.5 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = '$Revision: 1.7 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
-sub InstallerStart {
-    my $Self = shift;
-    my %Param = @_;
-
-    # create & return output
-    return $Self->InstallerBody(
-        %Param,
-        Body => $Self->Output(TemplateFile => 'InstallerStart', Data => \%Param),
-    );
-}
 # --
 sub InstallerSystem {
     my $Self = shift;
@@ -53,14 +42,6 @@ sub InstallerSystem {
     return $Self->Output(TemplateFile => 'InstallerSystem', Data => \%Param);
 }
 # --
-sub InstallerFinish {
-    my $Self = shift;
-    my %Param = @_;
-
-    # create & return output
-    return $Self->Output(TemplateFile => 'InstallerFinish', Data => \%Param);
-}
-# --
 sub InstallerBody {
     my $Self = shift;
     my %Param = @_;
@@ -71,4 +52,3 @@ sub InstallerBody {
 # --
 
 1;
- 
