@@ -2,7 +2,7 @@
 # Kernel/System/CustomerUser/DB.pm - some customer user functions
 # Copyright (C) 2002-2003 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: DB.pm,v 1.6.2.2 2003/02/11 12:40:48 wiktor Exp $
+# $Id: DB.pm,v 1.14 2003/04/22 20:31:56 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,8 +15,8 @@ use strict;
 use Kernel::System::CheckItem;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.6.2.2 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = '$Revision: 1.14 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
 sub new {
@@ -33,6 +33,10 @@ sub new {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
     # --
+    # max shown user a search list
+    # --
+    $Self->{UserSearchListLimit} = 250;
+    # --
     # config options
     # --
     $Self->{CustomerTable} = $Self->{ConfigObject}->Get('CustomerUser')->{Params}->{Table} 
@@ -48,14 +52,64 @@ sub new {
     return $Self;
 }
 # --
+sub CustomerName {
+    my $Self = shift;
+    my %Param = @_;
+    my $Name = ''; 
+    # --
+    # check needed stuff
+    # --
+    if (!$Param{UserLogin}) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need UserLogin!");
+        return;
+    }
+    # --
+    # build SQL string 1/2
+    # --
+    my $SQL = "SELECT $Self->{CustomerKey} ";
+    if ($Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserNameFields}) {
+        foreach my $Entry (@{$Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserNameFields}}) {
+            $SQL .= ", $Entry";
+        }
+    }
+    else {
+        $SQL .= " , first_name, last_name ";
+    }
+    $SQL .= " FROM $Self->{CustomerTable} WHERE ".
+      " $Self->{CustomerKey} = '".$Self->{DBObject}->Quote($Param{UserLogin})."'";
+    # --
+    # get data
+    # --
+    $Self->{DBObject}->Prepare(SQL => $SQL, Limit => 1);
+    while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+        foreach (1..8) {
+            if ($Row[$_]) {
+                if (!$Name) {
+                    $Name = $Row[$_];
+                }
+                else {
+                    $Name .= ' '.$Row[$_];
+                }
+            }
+        }
+    }
+    return $Name;
+}
+# --
 sub CustomerSearch {
     my $Self = shift;
     my %Param = @_;
     my %Users = ();
     # --
-    # build SQL string
+    # check needed stuff
+    # --
+    if (!$Param{Search} && !$Param{UserLogin}) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need Search or UserLogin!");
+        return;
+    }
+    # --
+    # build SQL string 1/2
     # --
-    $Param{UserLogin} =~ s/\*/%/g;
     my $SQL = "SELECT $Self->{CustomerKey} ";
     if ($Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserListFields}) {
         foreach my $Entry (@{$Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserListFields}}) {
@@ -66,18 +120,42 @@ sub CustomerSearch {
         $SQL .= " , first_name, last_name, email ";
     }
     # --
-    # get data
+    # build SQL string 2/2
     # --
     $SQL .= " FROM " .
     " $Self->{CustomerTable} ".
-    " WHERE " .
-    " $Self->{CustomerKey} LIKE '$Param{UserLogin}' ";
+    " WHERE ";
+    if ($Param{Search}) { 
+        $Param{Search} =~ s/\*/%/g;
+        if ($Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserSearchFields}) {
+            my $SQLExt = '';
+            foreach (@{$Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserSearchFields}}) {
+                if ($SQLExt) {
+                    $SQLExt .= ' OR ';
+                }
+                $SQLExt .= " $_ LIKE '".$Self->{DBObject}->Quote($Param{Search})."' ";
+            }
+            $SQL .= $SQLExt;
+        }
+        else {
+            $SQL .= " $Self->{CustomerKey} LIKE '".$Self->{DBObject}->Quote($Param{Search})."' ";
+        }
+    }
+    if ($Param{UserLogin}) {
+        $Param{UserLogin} =~ s/\*/%/g;
+        $SQL .= " $Self->{CustomerKey} LIKE '".$Self->{DBObject}->Quote($Param{UserLogin})."'";
+    }
+    # --
     # add valid option
+    # --
     if ($Self->{ConfigObject}->Get('CustomerUser')->{CustomerValid}) {
         $SQL .= "AND ".$Self->{ConfigObject}->Get('CustomerUser')->{CustomerValid}.
         " in ( ${\(join ', ', $Self->{DBObject}->GetValidIDs())} ) ";
     }
-    $Self->{DBObject}->Prepare(SQL => $SQL);
+    # --
+    # get data
+    # --
+    $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Self->{UserSearchListLimit});
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
          foreach (1..8) {
              if ($Row[$_]) {
@@ -89,34 +167,6 @@ sub CustomerSearch {
     return %Users;
 }
 # --
-sub CustomerList {
-    my $Self = shift;
-    my %Param = @_;
-    my $Valid = defined $Param{Valid} ? $Param{Valid} : 1;
-    # --
-    # build SQL string
-    # --
-    my $SQL = '';
-    if ($Self->{ConfigObject}->Get('CustomerUser')->{CustomerListFileds}) {
-        foreach my $Entry (@{$Self->{ConfigObject}->Get('CustomerUser')->{CustomerListFileds}}) {
-            $SQL .= " ,$Entry ";
-        }
-    }
-    else {
-        $SQL .= " , customer_id, comment";
-    }
-    # --
-    # get data
-    # --
-    my %Users = $Self->{DBObject}->GetTableData(
-        What => "$Self->{CustomerID} $SQL ",
-        Table => $Self->{CustomerTable}, 
-        Clamp => 1,
-        Valid => $Valid,
-    ); 
-    return %Users;
-}
-# --
 sub CustomerUserList {
     my $Self = shift;
     my %Param = @_;
@@ -153,10 +203,10 @@ sub CustomerUserDataGet {
     }
     $SQL .= $Self->{CustomerKey}." FROM $Self->{CustomerTable} WHERE ";
     if ($Param{User}) {
-        $SQL .= $Self->{CustomerKey}." = '$Param{User}'";
+        $SQL .= $Self->{CustomerKey}." = '".$Self->{DBObject}->Quote($Param{User})."'";
     }
     elsif ($Param{CustomerID}) {
-        $SQL .= $Self->{CustomerID}." = '$Param{CustomerID}'";
+        $SQL .= $Self->{CustomerID}." = '".$Self->{DBObject}->Quote($Param{CustomerID})."'";
     }
     # --
     # get inital data
@@ -173,10 +223,10 @@ sub CustomerUserDataGet {
     # check data
     # --
     if (! exists $Data{UserLogin} && $Param{User}) {
-        $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "Panic! No UserData for customer user: '$Param{User}'!!!",
-        );
+#        $Self->{LogObject}->Log(
+#          Priority => 'notice',
+#          Message => "Panic! No UserData for customer user: '$Param{User}'!!!",
+#        );
         return;
     }
     if (! exists $Data{UserLogin} && $Param{CustomerID}) {
@@ -225,13 +275,6 @@ sub CustomerUserAdd {
         return;
     }
     # --
-    # quote params
-    # -- 
-    $Param{UserPassword} = crypt($Param{UserPassword}, $Param{UserLogin});
-    foreach (keys %Param) {
-       $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
-    }
-    # --
     # build insert
     # --
     my $SQL = "INSERT INTO $Self->{CustomerTable} (";
@@ -245,7 +288,7 @@ sub CustomerUserAdd {
             $SQL .= " $Param{$Entry->[0]}, ";
         }
         else {
-            $SQL .= " '$Param{$Entry->[0]}', ";
+            $SQL .= " '".$Self->{DBObject}->Quote($Param{$Entry->[0]})."', ";
         }
     }
     $SQL .= "current_timestamp, $Param{UserID}, current_timestamp, $Param{UserID})";
@@ -257,6 +300,10 @@ sub CustomerUserAdd {
           Priority => 'notice',
           Message => "CustomerUser: '$Param{UserLogin}' created successfully ($Param{UserID})!",
       );
+      # --
+      # set password
+      # --
+      $Self->SetPassword(UserLogin => $Param{UserLogin}, PW => $Param{UserPassword});
       return $Param{UserLogin}; 
     }
     else {
@@ -291,12 +338,6 @@ sub CustomerUserUpdate {
     # get old user data (pw)
     # --
     my %UserData = $Self->CustomerUserDataGet(User => $Param{ID});
-    # --
-    # quote params
-    # -- 
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
-    }
     # -- 
     # update db
     # --
@@ -306,12 +347,12 @@ sub CustomerUserUpdate {
             $SQL .= " $Entry->[2] = $Param{$Entry->[0]}, ";
         }
         elsif ($Entry->[0] !~ /^UserPassword$/i) {
-            $SQL .= " $Entry->[2] = '$Param{$Entry->[0]}', ";
+            $SQL .= " $Entry->[2] = '".$Self->{DBObject}->Quote($Param{$Entry->[0]})."', ";
         }
     }
     $SQL .= " change_time = current_timestamp, ";
     $SQL .= " change_by = $Param{UserID} ";
-    $SQL .= " WHERE ".$Self->{CustomerKey}." = '$Param{ID}'";
+    $SQL .= " WHERE ".$Self->{CustomerKey}." = '".$Self->{DBObject}->Quote($Param{ID})."'";
   
     if ($Self->{DBObject}->Do(SQL => $SQL)) {
         # --
@@ -347,9 +388,30 @@ sub SetPassword {
         return;
     }
     # --
-    # crypt pw
-    # --    
-    my $NewPw = $Self->{DBObject}->Quote(crypt($Pw, $Param{UserLogin}));
+    # crypt given pw (unfortunately there is a mod_perl2 bug on RH8 - check if 
+    # crypt() is working correctly) :-/
+    # --
+    my $CryptedPw = '';
+    if (crypt('root', 'root@localhost') eq 'roK20XGbWEsSM') {
+        $CryptedPw = crypt($Pw, $Param{UserLogin});
+    }
+    else {
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "The crypt() of your mod_perl(2) is not working correctly! Update mod_perl!",
+        );
+        my $TempUser = $Param{UserLogin};
+        $TempUser =~ s/'/\\'/g;
+        my $TempPw = $Pw;
+        $TempPw =~ s/'/\\'/g;
+        my $CMD = "perl -e \"print crypt('$TempPw', '$TempUser');\"";
+        open (IO, " $CMD | ") || print STDERR "Can't open $CMD: $!";
+        while (<IO>) {
+            $CryptedPw .= $_;
+        }
+        close (IO);
+        chomp $CryptedPw;
+    }
     # --
     # update db
     # --
@@ -364,9 +426,9 @@ sub SetPassword {
     if ($Self->{DBObject}->Do(
             SQL => "UPDATE $Self->{CustomerTable} ".
                " SET ".
-               " $Param{PasswordCol} = '$NewPw' ".
+               " $Param{PasswordCol} = '".$Self->{DBObject}->Quote($CryptedPw)."' ".
                " WHERE ".
-               " $Param{LoginCol} = '$Param{UserLogin}'",
+               " $Param{LoginCol} = '".$Self->{DBObject}->Quote($Param{UserLogin})."'",
     )) {
         # --
         # log notice
