@@ -3,7 +3,7 @@
 # Copyright (C) 2002-2003 Martin Edenhofer <martin+code@otrs.org>
 # Copyright (C) 2002 Stefan Schmidt <jsj@jsj.dyndns.org>
 # --
-# $Id: DateChecksum.pm,v 1.6 2003/01/27 11:38:33 martin Exp $
+# $Id: DateChecksum.pm,v 1.8 2003/03/18 15:35:30 wiktor Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -29,8 +29,8 @@ package Kernel::System::Ticket::Number::DateChecksum;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.6 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = '$Revision: 1.8 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub CreateTicketNr {
     my $Self = shift;
@@ -172,11 +172,16 @@ sub GetTNByString {
     # --
     # check ticket number
     # --
-    if ($String =~ /$TicketHook:+.{0,1}(\d{8,40})/i) {
+    if ($String =~ /$TicketHook:+.{0,1}(\d{8,40})\-FW/i) {
         return $1;
     }
     else {
-        return;
+        if ($String =~ /$TicketHook:+.{0,1}(\d{8,40})/i) {
+            return $1;
+        }
+        else {
+            return;
+        }
     }
 }
 # --
